@@ -13,7 +13,10 @@ from summ.pipeline import Pipeline as Pipeline
 from summ.summ import Summ as Summ
 
 if pinecone_api_key := os.environ.get("PINECONE_API_KEY"):
-    pinecone.init(api_key=pinecone_api_key)
+    pinecone.init(
+        api_key=pinecone_api_key,
+        environment=os.environ.get("PINECONE_ENVIRONMENT", "us-west1-gcp"),
+    )
 
 langchain.llm_cache = RedisCache(redis_=Redis(db=1))
 
@@ -22,7 +25,7 @@ try:
         raise TypeError
 except TypeError as e:
     raise Exception(
-        "Redisearch not installed. Try `brew install redis-stack/redis-stack/redis-stack"
+        "Redisearch not installed. Try `brew reinstall yasyf/summ/redis-stack"
     ) from e
 else:
     Migrator().run()
