@@ -85,10 +85,13 @@ class SettingsScreen(Screen):
         yield Footer()
 
     def on_mount(self):
-        if not self.settings.corpus_path:
-            self.settings = self.settings.copy(
-                update={"corpus_path": self.app.pipe.importer.dir}
-            )
+        if (
+            not self.settings.corpus_path
+            or not Path(self.settings.corpus_path).exists()
+        ):
+            field = self.query_one("#corpus_path", Input)
+            field.value = str(self.app.pipe.importer.dir)
+            field.focus()
 
     def on_button_pressed(self, event: Button.Pressed):
         if event.button.id == "save":
